// 将记录列表转换为KeyRecord
export function getKeyRecordList(list, fieldList = [], convertOptionName = false) {
    if (Array.isEmpty(list)) {
        return list;
    }
    const result = [];
    list.forEach(record => {
        result.push(getKeyRecord0(record, fieldList, convertOptionName));
    });
    return result;
}

/**
 * 获取将表单的记录转换为
 * {
 *     字段标识符key:value
 * }
 * @param record
 * @param fieldList
 * @returns {null|{id}}
 */
export function getKeyRecord(record, fieldList) {
    return getKeyRecord0(record, fieldList, true);
}

function getKeyRecord0(record, fieldList, convertOptionName) {
    if (record == null || Array.isEmpty(fieldList)) {
        return null;
    }
    const newItem = {};
    if (String.isNotEmpty(record.id)) {
        newItem.id = record.id;
    }
    if (record._rowid) {
        newItem['_rowid'] = record._rowid;
    }
    if (record.$deleted) {
        newItem['$deleted'] = record.$deleted;
    }
    if (record.$selected) {
        newItem['$selected'] = record.$selected;
    }
    if (record.$updateKeyFields) {
        newItem['$updateKeyFields'] = record.$updateKeyFields;
    }
    fieldList.forEach(f => {
        const value = record[f.id];
        if (f.type === 'RelationRecord') {
            newItem[`${f.key}_name`] = record[`${f.id}_name`];
        }
        if (value == null) {
            return;
        }
        newItem[f.key] = value;
        if (f.type === 'CreateUser' || f.type === 'LastModifyUser') {
            newItem[`${f.key}_name`] = record[`${f.id}_name`];
            newItem[`${f.key}_avatar`] = record[`${f.id}_avatar`];
        }
        if (convertOptionName) {
            //将字典值的名称拼接返回
            if (f.type === 'ListSelect') {
                newItem[`${f.key}_name`] = getOptionName(f.setting.optionList, false, value);
            }
            if (f.type === 'Tree') {
                newItem[`${f.key}_name`] = getOptionName(f.setting.optionList, true, value);
            }
            if (f.type === 'Cascader') {
                if (Array.isArray(value)) {
                    const ret = [];
                    value.forEach(item => {
                        ret.push(getOptionName(f.setting.optionList, true, item));
                    });
                    newItem[`${f.key}_name`] = ret;
                }
            }
        }
    });
    return newItem;
}

function getOptionName(optionList, isTree, value) {
    let list = optionList;
    if (isTree) {
        list = optionList.asList();
    }
    if (Array.isArray(value)) {
        const t = [];
        value.forEach(k => {
            const option = list.findById(k);
            if (option) {
                t.push(option.name);
            } else {
                t.push(k);
            }
        });
        return t;
    } else {
        const option = list.findById(value);
        if (option) {
            return option.name;
        } else {
            return value;
        }
    }
}
