const { defineConfig } = require('@vue/cli-service');
const path = require('path');
// 是否是生产环境打包
const isProd = process.env.NODE_ENV !== 'development';

function resolve(dir) {
    return path.join(__dirname, dir);
}

module.exports = defineConfig({
    transpileDependencies: true,
    lintOnSave: !isProd,
    productionSourceMap: !isProd,
    publicPath: './',
    configureWebpack: {
        resolve: {
            alias: {
                '@': resolve('src'),
                '@assets': resolve('src/assets'),
                '@styles': resolve('src/assets/styles')
            }
        }
    },
    css: {
        extract: isProd ? { ignoreOrder: true } : false,
        loaderOptions: {
            sass: {
                additionalData: `@import "~@/assets/styles/variables.scss";`
            }
        }
    },
    devServer: {
        allowedHosts: 'all',
        open: {
            target: 'http://localhost:8080'
        },
        hot: true,
        https: false,
        compress: true,
        webSocketServer: 'ws',
        client: {
            progress: true,
            reconnect: true,
            webSocketTransport: 'ws',
            webSocketURL: {
                protocol: 'ws'
            },
            overlay: {
                errors: true,
                warnings: false
            }
        }
    }
});
